#
# spec file for package python-msgspec
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-msgspec
Version:        0.18.6
Release:        2.3
Summary:        A fast serialization and validation library
License:        BSD-3-Clause
URL:            https://jcristharif.com/msgspec/
Source:         https://github.com/jcrist/msgspec/archive/refs/tags/%{version}.tar.gz#/msgspec-%{version}.tar.gz
# PATCH-FIX-UPSTREAM: gh#jcrist/msgspec#711
Patch1:         python313.patch
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Suggests:       python-msgpack
Suggests:       python-attrs
Suggests:       python-furo
Suggests:       python-ipython
Suggests:       python-tomli_w
Suggests:       python-pyyaml
%python_subpackages

%description
A fast serialization and validation library, with builtin support for JSON, MessagePack, YAML, and TOML.

%prep
%autosetup -p1 -n msgspec-%{version}

%build
export CFLAGS="%{optflags}"
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
%pytest_arch

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitearch}/msgspec
%{python_sitearch}/msgspec-%{version}.dist-info

%changelog
* Mon Oct 28 2024 Dirk Müller <dmueller@suse.com>
- add python313.patch: support python 3.13
* Tue Jan 30 2024 Dirk Müller <dmueller@suse.com>
- update to 0.18.6:
  * Support coercing integral floats to ints when strict=False
  * Preserve leading _ when renaming fields to camel or pascal
    case
  * Support zero-copy decoding binary fields to a memoryview
  * Fix a bug when inheriting from the same Generic base class
    multiple times
  * Add an order option to all encoders for enforcing
    deterministic/sorted ordering when encoding. This can help
    provide a more consistent or human readable output
  * Support inheriting from any slots-class when defining a new
    Struct type with gc=False
  * Automatically infer the input field naming convention when
    converting non-dict mappings or arbitrary objects to Struct
    types in msgspec.convert
* Wed Dec 27 2023 Dirk Müller <dmueller@suse.com>
- update to 0.18.5:
  * Support unhashable ``Annotated`` metadata in
    `msgspec.inspect.type_info`
  * Fix bug preventing decoding dataclasses/attrs types with
    default values and ``slots=True, frozen=True`` (:pr:`569`).
  * Support passing parametrized generic struct types to
    `msgspec.structs.fields`
  * Validate ``str`` constraints on dict keys when decoding
    msgpack (:pr:`577`).
  * Support ``UUID`` subclasses as inputs to `msgspec.convert`
  * Call ``__eq__`` from generated ``__ne__`` if user defines
    manual ``__eq__`` method on a ``Struct`` type (:pr:`593`).
  * Include the ``Struct`` type in the generated hash
  * Add a ``cache_hash`` struct option (:pr:`596`).
  * Fix a bug around caching of dataclass type info when dealing
    with subclasses of dataclasses (:pr:`599`).
  * Add `msgspec.structs.force_setattr` (:pr:`600`).
  * Support custom dict key types in JSON encoder and decoder
  * Include ``dict`` key constraints in generated JSON schema via
    the ``propertyNames`` field (:pr:`604`).
  * Add a ``schema_hook`` for generating JSON schemas for custom
    types
  * Add support for Python 3.12's ``type`` aliases (:pr:`606`).
* Thu Dec  7 2023 Dirk Müller <dmueller@suse.com>
- update to 0.18.4:
  * Resolve an issue leading to periodic segfaults when importing
    ``msgspec`` on CPython 3.12
  * Improve type annotation for ``Struct.__rich_repr__``
  * Add pre-built wheels for Python 3.12 (:pr:`558`)
* Fri Sep  1 2023 Steve Kowalik <steven.kowalik@suse.com>
- Initial release of 0.18.2.
